Method: FormatException.clean
- Defined in:
- lib/format_exception.rb
.clean(e, context_message = nil) ⇒ String
The log-friendly format
Formats the exception as the Rails logger would, with the exception class name and message on the first line, with the backtrace on subsequent, indented lines.
If the context_message is given, it is prepended to the first line.
140 141 142 |
# File 'lib/format_exception.rb', line 140 def self.clean(e, = nil) format(CLEAN_FORMAT, e, ) end |